PromptbetSdk class

Constructors

PromptbetSdk()

Properties

callbackFn ↔ dynamic Function(Map<String, dynamic>)
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isOverviewVisible bool
no setter
overlayEntry OverlayEntry?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userToken String
getter/setter pair

Methods

closeDialog() → void
dispose() Future<void>
Optional cleanup for consumers
getHealth(String clientUuid, {Map<String, dynamic>? params}) Future<bool>
initialize(String clientId, String userId, String clientSecret, dynamic callback(Map<String, dynamic>), {Map<String, dynamic>? params}) Future<bool>
initializeV2(String token, dynamic callback(Map<String, dynamic>), {Map<String, dynamic>? params}) Future<InitializationStatus>
launch(BuildContext context, {EdgeInsets padding = EdgeInsets.zero}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

sdkVersion → const String